@@ -1,5 +1,5 @@
 /* crypto.h --- Crypto prototypes.
- * Copyright (C) 2002, 2003, 2004, 2007  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2007, 2008  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -25,8 +25,6 @@
 
 #define SHISHI_DK_CONSTANT "\x6b\x65\x72\x62\x65\x72\x6f\x73"
 
-extern int _shishi_crypto_init (Shishi * handle);
-
 int
 _shishi_simplified_derivekey (Shishi * handle,
 			      Shishi_key * key,
@@ -118,11 +116,11 @@ struct cipherinfo
 {
   int32_t type;
   const char *name;
-  int blocksize;
-  int confoundersize;
-  int keylen;
-  int randomlen;
-  int defaultcksumtype;
+  size_t blocksize;
+  size_t confoundersize;
+  size_t keylen;
+  size_t randomlen;
+  uint32_t defaultcksumtype;
   Shishi_random_to_key_function random2key;
   Shishi_string_to_key_function string2key;
   Shishi_encrypt_function encrypt;
